@@ -30,7 +30,7 @@ class Decoder:
                     raise McapError(
                         f"Can't decode schema with encoding {record.encoding}"
                     )
-                if not record.name in msg_types:
+                if record.name not in msg_types:
                     msg_type = dynamic.generate_dynamic(  # type: ignore
                         record.name, record.data.decode()
                     )
